# -*- coding: utf-8 -*-

# This file is part of djubby <http://djubby.googlecode.com/>,
# a Linked Data frontend for SPARQL endpoints for the Django Web framework
#
# Copyright (C) 2010 Sergio Fernández
#
# Djubby is free software: you can redistribute it and/or modify it 
# under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Djubby is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Djubby. If not, see <http://www.gnu.org/licenses/>.

from rdflib import Namespace

rdf    = Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
rdfs   = Namespace("http://www.w3.org/2000/01/rdf-schema#")
xsd    = Namespace("http://www.w3.org/2001/XMLSchema#")
owl    = Namespace("http://www.w3.org/2002/07/owl#")
config = Namespace("http://richard.cyganiak.de/2007/pubby/config.rdf#")
dc     = Namespace("http://purl.org/dc/elements/1.1/")
dct    = Namespace("http://purl.org/dc/terms/")
skos   = Namespace("http://www.w3.org/2004/02/skos/core#")
foaf   = Namespace("http://xmlns.com/foaf/0.1/")

